USE AdventureWorks2012
GO
WITH HR AS (
SELECT dep.DepartmentID,
       GroupName,
       edh.BusinessEntityID AS EmployeeID,
       FirstName,
       LastName
  FROM HumanResources.Department AS dep
       INNER JOIN HumanResources.EmployeeDepartmentHistory AS edh
       ON dep.DepartmentID = edh.DepartmentID 
       INNER JOIN HumanResources.Employee AS emp
       ON emp.BusinessEntityID = edh.BusinessEntityID
       INNER JOIN Person.Person AS p
       ON p.BusinessEntityID = emp.BusinessEntityID
 WHERE dep.DepartmentID < 3
 )
SELECT DepartmentID AS "@Dep-ID",
       GroupName,
       EmployeeID   AS "Emp/@Emp-ID",
       FirstName + ' ' + LastName AS "Emp/Name"
  FROM hr
FOR XML PATH('Dep'), ROOT('Dep-List')

-- Relationales Ergebnis der CTE
/*
Dep-ID GroupName                      EmployeeID  FirstName     LastName
------ ------------------------------ ----------- ------------- ---------------
1      Research and Development       3           Roberto       Tamburello
1      Research and Development       4           Rob           Walters
1      Research and Development       9           Gail          Erickson
1      Research and Development       11          Jossef        Goldberg
1      Research and Development       12          Terri         Duffy
1      Research and Development       267         Michael       Sullivan
1      Research and Development       270         Sharon        Salavaria
2      Research and Development       4           Rob           Walters
2      Research and Development       5           Thierry       D'Hers
2      Research and Development       263         Ovidiu        Cracium
2      Research and Development       265         Janice        Galvin

(11 Zeile(n) betroffen)
*/

-- Ergebnis in XML der gesamten Abfrage
/*
<Dep-List>
  <Dep Dep-ID="1">
    <GroupName>Research and Development</GroupName>
    <Emp Emp-ID="3">
      <Name>Roberto Tamburello</Name>
    </Emp>
  </Dep>
  <Dep Dep-ID="1">
    <GroupName>Research and Development</GroupName>
    <Emp Emp-ID="4">
      <Name>Rob Walters</Name>
    </Emp>
  </Dep>
  <Dep Dep-ID="1">
    <GroupName>Research and Development</GroupName>
    <Emp Emp-ID="9">
      <Name>Gail Erickson</Name>
    </Emp>
  </Dep>
  <Dep Dep-ID="1">
    <GroupName>Research and Development</GroupName>
    <Emp Emp-ID="11">
      <Name>Jossef Goldberg</Name>
    </Emp>
  </Dep>
  <Dep Dep-ID="1">
    <GroupName>Research and Development</GroupName>
    <Emp Emp-ID="12">
      <Name>Terri Duffy</Name>
    </Emp>
  </Dep>
  <Dep Dep-ID="1">
    <GroupName>Research and Development</GroupName>
    <Emp Emp-ID="267">
      <Name>Michael Sullivan</Name>
    </Emp>
  </Dep>
  <Dep Dep-ID="1">
    <GroupName>Research and Development</GroupName>
    <Emp Emp-ID="270">
      <Name>Sharon Salavaria</Name>
    </Emp>
  </Dep>
  <Dep Dep-ID="2">
    <GroupName>Research and Development</GroupName>
    <Emp Emp-ID="4">
      <Name>Rob Walters</Name>
    </Emp>
  </Dep>
  <Dep Dep-ID="2">
    <GroupName>Research and Development</GroupName>
    <Emp Emp-ID="5">
      <Name>Thierry D'Hers</Name>
    </Emp>
  </Dep>
  <Dep Dep-ID="2">
    <GroupName>Research and Development</GroupName>
    <Emp Emp-ID="263">
      <Name>Ovidiu Cracium</Name>
    </Emp>
  </Dep>
  <Dep Dep-ID="2">
    <GroupName>Research and Development</GroupName>
    <Emp Emp-ID="265">
      <Name>Janice Galvin</Name>
    </Emp>
  </Dep>
</Dep-List>
*/