USE [AdventureWorks2012]
GO
-- XML Schema erzeugen
SELECT BusinessEntityID AS [Emp-ID],
       JobTitle         AS Title,
       BirthDate
  FROM HumanResources.Employee
 WHERE BusinessEntityID = 17
   FOR XML AUTO, XMLSCHEMA ('http://www.contoso.com')
GO
-- Ergebnis
/*
<xsd:schema targetNamespace="http://www.contoso.com" xmlns:schema="http://www.contoso.com" xmlns:xsd="http://www.w3.org/2001/XMLSchema" xmlns:sqltypes="http://schemas.microsoft.com/sqlserver/2004/sqltypes" elementFormDefault="qualified">
  <xsd:import namespace="http://schemas.microsoft.com/sqlserver/2004/sqltypes" schemaLocation="http://schemas.microsoft.com/sqlserver/2004/sqltypes/sqltypes.xsd" />
  <xsd:element name="HumanResources.Employee">
    <xsd:complexType>
      <xsd:attribute name="Emp-ID" type="sqltypes:int" use="required" />
      <xsd:attribute name="Title" use="required">
        <xsd:simpleType>
          <xsd:restriction base="sqltypes:nvarchar" sqltypes:localeId="1033" sqltypes:sqlCompareOptions="IgnoreCase IgnoreKanaType IgnoreWidth" sqltypes:sqlSortId="52">
            <xsd:maxLength value="50" />
          </xsd:restriction>
        </xsd:simpleType>
      </xsd:attribute>
      <xsd:attribute name="BirthDate" type="sqltypes:datetime" use="required" />
    </xsd:complexType>
  </xsd:element>
</xsd:schema>
<HumanResources.Employee xmlns="http://www.contoso.com" Emp-ID="17" Title="Production Technician - WC10" BirthDate="1946-05-06T00:00:00" />
*/

-- XML Schema mit Elementen erzeugen
SELECT DepartmentID,
       emp.BusinessEntityID AS [Emp-ID],
       JobTitle             AS Title
  FROM HumanResources.Employee AS emp INNER JOIN HumanResources.EmployeeDepartmentHistory AS edh
    ON emp.BusinessEntityID = edh.BusinessEntityID
 WHERE DepartmentID <3
   FOR XML AUTO, ELEMENTS, XMLSCHEMA ('http://www.contoso.com')
GO
-- Ergebnis
/*
<xsd:schema targetNamespace="http://www.contoso.com" xmlns:schema="http://www.contoso.com" xmlns:xsd="http://www.w3.org/2001/XMLSchema" xmlns:sqltypes="http://schemas.microsoft.com/sqlserver/2004/sqltypes" elementFormDefault="qualified">
  <xsd:import namespace="http://schemas.microsoft.com/sqlserver/2004/sqltypes" schemaLocation="http://schemas.microsoft.com/sqlserver/2004/sqltypes/sqltypes.xsd" />
  <xsd:element name="edh">
    <xsd:complexType>
      <xsd:sequence>
        <xsd:element name="DepartmentID" type="sqltypes:smallint" />
        <xsd:element ref="schema:emp" minOccurs="0" maxOccurs="unbounded" />
      </xsd:sequence>
    </xsd:complexType>
  </xsd:element>
  <xsd:element name="emp">
    <xsd:complexType>
      <xsd:sequence>
        <xsd:element name="Emp-ID" type="sqltypes:int" />
        <xsd:element name="Title">
          <xsd:simpleType>
            <xsd:restriction base="sqltypes:nvarchar" sqltypes:localeId="1033" sqltypes:sqlCompareOptions="IgnoreCase IgnoreKanaType IgnoreWidth" sqltypes:sqlSortId="52">
              <xsd:maxLength value="50" />
            </xsd:restriction>
          </xsd:simpleType>
        </xsd:element>
      </xsd:sequence>
    </xsd:complexType>
  </xsd:element>
</xsd:schema>
<edh xmlns="http://www.contoso.com">
  <DepartmentID>1</DepartmentID>
  <emp>
    <Emp-ID>3</Emp-ID>
    <Title>Engineering Manager</Title>
  </emp>
  <emp>
    <Emp-ID>4</Emp-ID>
    <Title>Senior Tool Designer</Title>
  </emp>
</edh>
<edh xmlns="http://www.contoso.com">
  <DepartmentID>2</DepartmentID>
  <emp>
    <Emp-ID>4</Emp-ID>
    <Title>Senior Tool Designer</Title>
  </emp>
  <emp>
    <Emp-ID>5</Emp-ID>
    <Title>Tool Designer</Title>
  </emp>
</edh>
<edh xmlns="http://www.contoso.com">
  <DepartmentID>1</DepartmentID>
  <emp>
    <Emp-ID>9</Emp-ID>
    <Title>Design Engineer</Title>
  </emp>
  <emp>
    <Emp-ID>11</Emp-ID>
    <Title>Design Engineer</Title>
  </emp>
  <emp>
    <Emp-ID>12</Emp-ID>
    <Title>Vice President of Engineering</Title>
  </emp>
</edh>
<edh xmlns="http://www.contoso.com">
  <DepartmentID>2</DepartmentID>
  <emp>
    <Emp-ID>263</Emp-ID>
    <Title>Senior Tool Designer</Title>
  </emp>
  <emp>
    <Emp-ID>265</Emp-ID>
    <Title>Tool Designer</Title>
  </emp>
</edh>
<edh xmlns="http://www.contoso.com">
  <DepartmentID>1</DepartmentID>
  <emp>
    <Emp-ID>267</Emp-ID>
    <Title>Senior Design Engineer</Title>
  </emp>
  <emp>
    <Emp-ID>270</Emp-ID>
    <Title>Design Engineer</Title>
  </emp>
</edh>
*/

